@@ -4,7 +4,7 @@ sentry.conf.server
 
 These settings act as the default (base) settings for the Sentry-provided web-server
 
-:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 
@@ -318,10 +318,12 @@ if os.path.exists(NPM_ROOT):
             "sentry/scripts/lib.min.js": {
                 "src": [
                     "sentry/scripts/lib/jquery.js",
-                    "sentry/scripts/lib/jquery.animate-colors-min.js",
+                    "sentry/scripts/lib/jquery-migrate.js",
+                    "sentry/scripts/lib/jquery.animate-colors.js",
                     "sentry/scripts/lib/jquery.clippy.min.js",
                     "sentry/scripts/lib/jquery.cookie.js",
                     "sentry/scripts/lib/jquery.flot.min.js",
+                    "sentry/scripts/lib/simple-slider.js",
                     "sentry/scripts/lib/json2.js",
                     "sentry/scripts/lib/underscore.js",
                     "sentry/scripts/lib/backbone.js",
