@@ -4,7 +4,7 @@ sentry.constants
 
 These settings act as the default (base) settings for the Sentry-provided web-server
 
-:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 
@@ -104,10 +104,14 @@ PLATFORM_LIST = (
     'r',
     'ruby',
     'rails3',
+    'sidekiq',
+    'sinatra',
 )
 
 PLATFORM_ROOTS = {
     'rails3': 'ruby',
+    'sinatra': 'ruby',
+    'sidekiq': 'ruby',
     'django': 'python',
     'flask': 'python',
     'express': 'node.js',
@@ -124,3 +128,8 @@ PLATFORM_TITLES = {
     'flask': 'Flask (Python)',
     'csharp': 'C#',
 }
+
+# Normalize counts to the 15 minute marker. This value MUST be less than 60. A
+# value of 0 would store counts for every minute, and is the lowest level of
+# accuracy provided.
+MINUTE_NORMALIZATION = 15
