@@ -2,7 +2,7 @@
 sentry.models
 ~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 
@@ -36,12 +36,15 @@ from django.utils.translation import ugettext_lazy as _
 from sentry.conf import settings
 from sentry.constants import (STATUS_LEVELS, MEMBER_TYPES,
     MEMBER_OWNER, MEMBER_USER, PLATFORM_TITLES, PLATFORM_LIST,
-    STATUS_VISIBLE, STATUS_HIDDEN)
+    STATUS_UNRESOLVED, STATUS_RESOLVED, STATUS_VISIBLE, STATUS_HIDDEN,
+    MINUTE_NORMALIZATION)
 from sentry.manager import (GroupManager, ProjectManager,
     MetaManager, InstanceMetaManager, SearchDocumentManager, BaseManager,
     UserOptionManager, FilterKeyManager, TeamManager)
 from sentry.signals import buffer_incr_complete, regression_signal
-from sentry.utils import cached_property, MockDjangoRequest
+from sentry.utils import MockDjangoRequest
+from sentry.utils.cache import memoize
+from sentry.utils.db import has_trending
 from sentry.utils.models import Model, GzippedDictField, update
 from sentry.utils.imports import import_string
 from sentry.utils.safe import safe_execute
@@ -101,13 +104,14 @@ class Team(Model):
     name = models.CharField(max_length=64)
     owner = models.ForeignKey(User)
     date_added = models.DateTimeField(default=timezone.now, null=True)
+    members = models.ManyToManyField(User, through='sentry.TeamMember', related_name='team_memberships')
 
     objects = TeamManager(cache_fields=(
         'pk',
         'slug',
     ))
 
-    __repr__ = sane_repr('slug', 'owner_id')
+    __repr__ = sane_repr('slug', 'owner_id', 'name')
 
     def save(self, *args, **kwargs):
         if not self.slug:
@@ -127,9 +131,40 @@ class Team(Model):
         return u'%s' % self.name
 
 
+class AccessGroup(Model):
+    """
+    An access group identifies a set of members with a defined set
+    of permissions (and project access) for a Team.
+
+    Groups may be automated through extensions (such as LDAP) so that
+    membership is automatically maintained. If this is the case the
+    ``managed`` attribute will be ``True``.
+    """
+    team = models.ForeignKey(Team)
+    name = models.CharField(max_length=64)
+    type = models.IntegerField(choices=MEMBER_TYPES, default=MEMBER_USER)
+    managed = models.BooleanField(default=False)
+    data = GzippedDictField(blank=True, null=True)
+    date_added = models.DateTimeField(default=timezone.now)
+
+    projects = models.ManyToManyField('sentry.Project')
+    members = models.ManyToManyField(User)
+
+    objects = BaseManager()
+
+    class Meta:
+        unique_together = (('team', 'name'),)
+
+    __repr__ = sane_repr('team_id', 'name', 'type', 'managed')
+
+
 class TeamMember(Model):
     """
     Identifies relationships between teams and users.
+
+    Users listed as team members are considered to have access to all projects
+    and could be thought of as team owners (though their access level may not)
+    be set to ownership.
     """
     team = models.ForeignKey(Team, related_name="member_set")
     user = models.ForeignKey(User, related_name="sentry_teammember_set")
@@ -256,6 +291,13 @@ class Project(Model):
             self._tag_cache = tags
         return self._tag_cache
 
+    # TODO: Make these a mixin
+    def update_option(self, *args, **kwargs):
+        return ProjectOption.objects.set_value(self, *args, **kwargs)
+
+    def get_option(self, *args, **kwargs):
+        return ProjectOption.objects.get_value(self, *args, **kwargs)
+
 
 class ProjectKey(Model):
     project = models.ForeignKey(Project, related_name='key_set')
@@ -511,6 +553,17 @@ class Group(EventBase):
     def natural_key(self):
         return (self.project, self.logger, self.culprit, self.checksum)
 
+    def is_over_resolve_age(self):
+        resolve_age = self.project.get_option('sentry:resolve_age', None)
+        if not resolve_age:
+            return False
+        return self.last_seen < timezone.now() - timedelta(hours=int(resolve_age))
+
+    def get_status(self):
+        if self.status == STATUS_UNRESOLVED and self.is_over_resolve_age():
+            return STATUS_RESOLVED
+        return self.status
+
     def get_score(self):
         return int(math.log(self.times_seen) * 600 + float(time.mktime(self.last_seen.timetuple())))
 
@@ -591,7 +644,7 @@ class Event(EventBase):
 
     __repr__ = sane_repr('project_id', 'group_id', 'checksum')
 
-    @cached_property
+    @memoize
     def request(self):
         data = self.data
         if 'META' in data:
@@ -619,7 +672,7 @@ class Event(EventBase):
         fake_request.path = fake_request.path_info
         return fake_request
 
-    @cached_property
+    @memoize
     def interfaces(self):
         result = []
         for key, data in self.data.iteritems():
@@ -688,6 +741,7 @@ class FilterKey(Model):
     """
     project = models.ForeignKey(Project)
     key = models.CharField(max_length=32)
+    values_seen = models.PositiveIntegerField(default=0)
 
     objects = FilterKeyManager()
 
@@ -704,6 +758,9 @@ class FilterValue(Model):
     project = models.ForeignKey(Project, null=True)
     key = models.CharField(max_length=32)
     value = models.CharField(max_length=200)
+    times_seen = models.PositiveIntegerField(default=0)
+    last_seen = models.DateTimeField(default=timezone.now, db_index=True, null=True)
+    first_seen = models.DateTimeField(default=timezone.now, db_index=True, null=True)
 
     objects = BaseManager()
 
@@ -713,6 +770,25 @@ class FilterValue(Model):
     __repr__ = sane_repr('project_id', 'key', 'value')
 
 
+class GroupTagKey(Model):
+    """
+    Stores a unique tag key name for a group.
+
+    An example key might be "url" or "server_name".
+    """
+    project = models.ForeignKey(Project, null=True)
+    group = models.ForeignKey(Group)
+    key = models.CharField(max_length=32)
+    values_seen = models.PositiveIntegerField(default=0)
+
+    objects = BaseManager()
+
+    class Meta:
+        unique_together = (('project', 'group', 'key'),)
+
+    __repr__ = sane_repr('project_id', 'group_id', 'key')
+
+
 class GroupTag(Model):
     """
     Stores the total number of messages seen by a group matching
@@ -970,8 +1046,62 @@ class Activity(Model):
                 self.event.update(num_comments=F('num_comments') + 1)
 
 
-### django-indexer
+class Alert(Model):
+    project = models.ForeignKey(Project)
+    group = models.ForeignKey(Group, null=True)
+    datetime = models.DateTimeField(default=timezone.now)
+    message = models.TextField()
+    data = GzippedDictField(null=True)
+    related_groups = models.ManyToManyField(Group, through='sentry.AlertRelatedGroup', related_name='related_alerts')
 
+    __repr__ = sane_repr('project_id', 'group_id', 'datetime')
+
+    @classmethod
+    def maybe_alert(cls, project_id, message, group_id=None):
+        now = timezone.now()
+        manager = cls.objects
+        # We only create an alert based on:
+        # - an alert for the project hasn't been created in the last 30 minutes
+        # - an alert for the event hasn't been created in the last 60 minutes
+
+        # TODO: there is a race condition if we're calling this function for the same project
+        if manager.filter(project=project_id, datetime__gte=now - timedelta(minutes=30)).exists():
+            return
+
+        if manager.filter(project=project_id, group=group_id, datetime__gte=now - timedelta(minutes=60)).exists():
+            return
+
+        alert = manager.create(
+            project_id=project_id,
+            group_id=group_id,
+            datetime=now,
+            message=message,
+        )
+
+        if not group_id and has_trending():
+            # Capture the top 5 trending events at the time of this error
+            related_groups = Group.objects.get_accelerated([project_id], minutes=MINUTE_NORMALIZATION)[:5]
+            for group in related_groups:
+                AlertRelatedGroup.objects.create(
+                    group=group,
+                    alert=alert,
+                )
+
+        return alert
+
+
+class AlertRelatedGroup(Model):
+    group = models.ForeignKey(Group)
+    alert = models.ForeignKey(Alert)
+    data = GzippedDictField(null=True)
+
+    class Meta:
+        unique_together = (('group', 'alert'),)
+
+    __repr__ = sane_repr('group_id', 'alert_id')
+
+
+### django-indexer
 
 class MessageIndex(BaseIndex):
     model = Event
@@ -1101,6 +1231,37 @@ def set_language_on_logon(request, user, **kwargs):
         request.session['django_language'] = language
 
 
+@buffer_incr_complete.connect(sender=FilterValue, weak=False)
+def record_project_tag_count(filters, created, **kwargs):
+    from sentry import app
+
+    if not created:
+        return
+
+    app.buffer.incr(FilterKey, {
+        'values_seen': 1,
+    }, {
+        'project': filters['project'],
+        'key': filters['key'],
+    })
+
+
+@buffer_incr_complete.connect(sender=GroupTag, weak=False)
+def record_group_tag_count(filters, created, **kwargs):
+    from sentry import app
+
+    if not created:
+        return
+
+    app.buffer.incr(GroupTagKey, {
+        'values_seen': 1,
+    }, {
+        'project': filters['project'],
+        'group': filters['group'],
+        'key': filters['key'],
+    })
+
+
 @buffer_incr_complete.connect(sender=AffectedUserByGroup, weak=False)
 def record_user_count(filters, created, **kwargs):
     from sentry import app
