@@ -2,7 +2,7 @@
 sentry.web.frontend.admin
 ~~~~~~~~~~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 import datetime
@@ -22,10 +22,11 @@ from django.http import HttpResponseRedirect
 from django.utils import timezone
 from django.views.decorators.csrf import csrf_protect
 
-from sentry import environment
+from sentry.app import env
 from sentry.conf import settings
 from sentry.models import Project, GroupCountByMinute
 from sentry.plugins import plugins
+from sentry.utils.http import absolute_uri
 from sentry.web.forms import NewUserForm, ChangeUserForm, RemoveUserForm, TestEmailForm
 from sentry.web.decorators import requires_admin
 from sentry.web.helpers import render_to_response, plugin_config, \
@@ -144,7 +145,7 @@ def create_new_user(request):
             context = {
                 'username': user.username,
                 'password': password,
-                'url': request.build_absolute_uri(reverse('sentry')),
+                'url': absolute_uri(reverse('sentry')),
             }
             if form.cleaned_data['create_project']:
                 context.update({
@@ -267,7 +268,7 @@ def status_env(request):
     return render_to_response('sentry/admin/status/env.html', {
         'python_version': sys.version,
         'config': config,
-        'environment': environment,
+        'environment': env.data,
     }, request)
 
 
